==> serverless-workflow-service-calls-springboot-1.3.0.Final-sources.jar: org/kie/kogito/handlers/ClassifierService_classifyLarge_15_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionError;

@org.springframework.stereotype.Component()
public class ClassifierService_classifyLarge_15_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.serverless.examples.ClassifierService service;

    public ClassifierService_classifyLarge_15_Handler() {
        this(new org.kie.kogito.serverless.examples.ClassifierService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public ClassifierService_classifyLarge_15_Handler(org.kie.kogito.serverless.examples.ClassifierService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.classifyLarge((com.fasterxml.jackson.databind.JsonNode) workItem.getParameter("Parameter"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("Result", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.serverless.examples.ClassifierService_classifyLarge_15_Handler";
    }
}

==> serverless-workflow-service-calls-springboot-1.4.0.Final-sources.jar: org/kie/kogito/handlers/ClassifierService_classifyLarge_15_Handler.java <==
package org.kie.kogito.handlers;

import org.kie.kogito.process.workitem.WorkItemExecutionException;

@org.springframework.stereotype.Component()
public class ClassifierService_classifyLarge_15_Handler implements org.kie.kogito.internal.process.runtime.KogitoWorkItemHandler {

    org.kie.kogito.serverless.examples.ClassifierService service;

    public ClassifierService_classifyLarge_15_Handler() {
        this(new org.kie.kogito.serverless.examples.ClassifierService());
    }

    @org.springframework.beans.factory.annotation.Autowired()
    @org.springframework.context.annotation.Lazy()
    public ClassifierService_classifyLarge_15_Handler(org.kie.kogito.serverless.examples.ClassifierService service) {
        this.service = service;
    }

    public void executeWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
        java.lang.Object result;
        result = service.classifyLarge((com.fasterxml.jackson.databind.JsonNode) workItem.getParameter("Parameter"));
        workItemManager.completeWorkItem(workItem.getStringId(), java.util.Collections.singletonMap("Result", result));
    }

    public void abortWorkItem(org.kie.kogito.internal.process.runtime.KogitoWorkItem workItem, org.kie.kogito.internal.process.runtime.KogitoWorkItemManager workItemManager) {
    }

    public String getName() {
        return "org.kie.kogito.serverless.examples.ClassifierService_classifyLarge_15_Handler";
    }
}
